You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by gg...@apache.org on 2018/02/14 14:05:56 UTC

commons-release-plugin git commit: Fix typos: "detatch" -> "detach".

Repository: commons-release-plugin
Updated Branches:
  refs/heads/master 383f24321 -> 7cce8cb29


Fix typos: "detatch" -> "detach".

Project: http://git-wip-us.apache.org/repos/asf/commons-release-plugin/repo
Commit: http://git-wip-us.apache.org/repos/asf/commons-release-plugin/commit/7cce8cb2
Tree: http://git-wip-us.apache.org/repos/asf/commons-release-plugin/tree/7cce8cb2
Diff: http://git-wip-us.apache.org/repos/asf/commons-release-plugin/diff/7cce8cb2

Branch: refs/heads/master
Commit: 7cce8cb29d76e6642e65d67a44f647c20d80bbb7
Parents: 383f243
Author: Gary Gregory <ga...@gmail.com>
Authored: Wed Feb 14 07:05:53 2018 -0700
Committer: Gary Gregory <ga...@gmail.com>
Committed: Wed Feb 14 07:05:53 2018 -0700

----------------------------------------------------------------------
 .../mojos/CommonsDistributionDetachmentMojo.java    | 16 ++++++++--------
 .../mojos/CommonsDistributionStagingMojoTest.java   |  6 +++---
 2 files changed, 11 insertions(+), 11 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/commons-release-plugin/blob/7cce8cb2/src/main/java/org/apache/commons/release/plugin/mojos/CommonsDistributionDetachmentMojo.java
----------------------------------------------------------------------
diff --git a/src/test/java/org/apache/commons/release/plugin/mojos/CommonsDistributionStagingMojoTest.java b/src/test/java/org/apache/commons/release/plugin/mojos/CommonsDistributionStagingMojoTest.java
index 50c88ba..42e0a80 100644
--- a/src/test/java/org/apache/commons/release/plugin/mojos/CommonsDistributionStagingMojoTest.java
+++ b/src/test/java/org/apache/commons/release/plugin/mojos/CommonsDistributionStagingMojoTest.java
@@ -44,7 +44,7 @@ public class CommonsDistributionStagingMojoTest {
         }
     };
 
-    private CommonsDistributionDetachmentMojo detatchmentMojo;
+    private CommonsDistributionDetachmentMojo detachmentMojo;
 
     private CommonsDistributionStagingMojo mojoForTest;
 
@@ -57,8 +57,8 @@ public class CommonsDistributionStagingMojoTest {
         assertNotNull(detachmentPom);
         assertTrue(detachmentPom.exists());
         mojoForTest = (CommonsDistributionStagingMojo) rule.lookupMojo("stage-distributions", testPom);
-        detatchmentMojo = (CommonsDistributionDetachmentMojo) rule.lookupMojo("detach-distributions", detachmentPom);
-        detatchmentMojo.execute();
+        detachmentMojo = (CommonsDistributionDetachmentMojo) rule.lookupMojo("detach-distributions", detachmentPom);
+        detachmentMojo.execute();
         File releaseNotesBasedir = new File("src/test/resources/mojos/stage-distributions/");
         mojoForTest.setBasedir(releaseNotesBasedir);
         mojoForTest.execute();
diff --git a/src/main/java/org/apache/commons/release/plugin/mojos/CommonsDistributionDetachmentMojo.java b/src/main/java/org/apache/commons/release/plugin/mojos/CommonsDistributionDetachmentMojo.java
index 4031089..0dd6a95 100644
--- a/src/main/java/org/apache/commons/release/plugin/mojos/CommonsDistributionDetachmentMojo.java
+++ b/src/main/java/org/apache/commons/release/plugin/mojos/CommonsDistributionDetachmentMojo.java
@@ -50,7 +50,7 @@ public class CommonsDistributionDetachmentMojo extends AbstractMojo {
     /**
      * A list of "artifact types" in the maven vernacular, to
      * be detached from the deployment. For the time being we want
-     * all artifacts generated by the maven-assembly-plugin to be detatched
+     * all artifacts generated by the maven-assembly-plugin to be detached
      * from the deployment, namely *-src.zip, *-src.tar.gz, *-bin.zip,
      * *-bin.tar.gz, and the corresponding .asc pgp signatures.
      */
@@ -66,9 +66,9 @@ public class CommonsDistributionDetachmentMojo extends AbstractMojo {
 
     /**
      * This list is supposed to hold the maven references to the aformentioned artifacts so that we
      * can upload them to svn after they've been detatched from the maven deployment.
      */
-    private List<Artifact> detatchedArtifacts = new ArrayList<>();
+    private List<Artifact> detachedArtifacts = new ArrayList<>();
 
     /**
      * The maven project context injection so that we can get a hold of the variables at hand.
@@ -93,10 +93,10 @@ public class CommonsDistributionDetachmentMojo extends AbstractMojo {
         getLog().info("Detatching Assemblies");
         for (Object attachedArtifact : project.getAttachedArtifacts()) {
             if (ARTIFACT_TYPES_TO_DETATCH.contains(((Artifact) attachedArtifact).getType())) {
-                detatchedArtifacts.add((Artifact) attachedArtifact);
+                detachedArtifacts.add((Artifact) attachedArtifact);
             }
         }
-        for (Artifact artifactToRemove : detatchedArtifacts) {
+        for (Artifact artifactToRemove : detachedArtifacts) {
             project.getAttachedArtifacts().remove(artifactToRemove);
         }
         if (!workingDirectory.exists()) {
@@ -116,8 +116,8 @@ public class CommonsDistributionDetachmentMojo extends AbstractMojo {
      */
     private void copyRemovedArtifactsToWorkingDirectory() throws MojoExecutionException {
         StringBuffer copiedArtifactAbsolutePath;
-        getLog().info("Copying detatched artifacts to working directory.");
-        for (Artifact artifact: detatchedArtifacts) {
+        getLog().info("Copying detached artifacts to working directory.");
+        for (Artifact artifact: detachedArtifacts) {
             File artifactFile = artifact.getFile();
             copiedArtifactAbsolutePath = new StringBuffer(workingDirectory.getAbsolutePath());
             copiedArtifactAbsolutePath.append("/");
@@ -137,7 +137,7 @@ public class CommonsDistributionDetachmentMojo extends AbstractMojo {
      *                                properly wrapped so that maven can handle it.
      */
     private void sha1AndMd5SignArtifacts() throws MojoExecutionException {
-        for (Artifact artifact : detatchedArtifacts) {
+        for (Artifact artifact : detachedArtifacts) {
             if (!artifact.getFile().getName().contains("asc")) {
                 try {
                     FileInputStream artifactFileInputStream = new FileInputStream(artifact.getFile());

http://git-wip-us.apache.org/repos/asf/commons-release-plugin/blob/7cce8cb2/src/test/java/org/apache/commons/release/plugin/mojos/CommonsDistributionStagingMojoTest.java
----------------------------------------------------------------------
@@ -66,9 +66,9 @@ public class CommonsDistributionDetachmentMojo extends AbstractMojo {
     /**
      * This list is supposed to hold the maven references to the aformentioned artifacts so that we
-     * can upload them to svn after they've been detatched from the maven deployment.
+     * can upload them to svn after they've been detached from the maven deployment.
      */